pub struct WireExecuteRequest {
pub tool_call_id: String,
pub enabled_tools: Vec<WireToolDefinition>,
pub source: String,
pub yield_time_ms: Option<u64>,
pub max_output_tokens: Option<i32>,
}Expand description
The complete execute request shape supported by protocol V1.
Fields
tool_call_id: Stringenabled_tools: Vec<WireToolDefinition>source: Stringyield_time_ms: Option<u64>max_output_tokens: Option<i32>Trait Implementations
Sourceimpl Clone for WireExecuteRequest
impl Clone for WireExecuteRequest
Sourcefn clone(&self) -> WireExecuteRequest
fn clone(&self) -> WireExecuteRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WireExecuteRequest
impl Debug for WireExecuteRequest
Sourceimpl<'de> Deserialize<'de> for WireExecuteRequest
impl<'de> Deserialize<'de> for WireExecuteRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for WireExecuteRequest
impl PartialEq for WireExecuteRequest
Sourceimpl Serialize for WireExecuteRequest
impl Serialize for WireExecuteRequest
impl StructuralPartialEq for WireExecuteRequest
Sourceimpl TryFrom<ExecuteRequest> for WireExecuteRequest
impl TryFrom<ExecuteRequest> for WireExecuteRequest
Sourcetype Error = TryFromIntError
type Error = TryFromIntError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<WireExecuteRequest> for ExecuteRequest
impl TryFrom<WireExecuteRequest> for ExecuteRequest
Sourcetype Error = TryFromIntError
type Error = TryFromIntError
The type returned in the event of a conversion error.