pub struct ExecuteRequest {
pub tool_call_id: String,
pub enabled_tools: Vec<ToolDefinition>,
pub source: String,
pub yield_time_ms: Option<u64>,
pub max_output_tokens: Option<usize>,
}Fields
tool_call_id: Stringenabled_tools: Vec<ToolDefinition>source: Stringyield_time_ms: Option<u64>max_output_tokens: Option<usize>Trait Implementations
Sourceimpl Clone for ExecuteRequest
impl Clone for ExecuteRequest
Sourcefn clone(&self) -> ExecuteRequest
fn clone(&self) -> ExecuteRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExecuteRequest
impl Debug for ExecuteRequest
Sourceimpl<'de> Deserialize<'de> for ExecuteRequest
impl<'de> Deserialize<'de> for ExecuteRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ExecuteRequest
impl PartialEq for ExecuteRequest
Sourceimpl Serialize for ExecuteRequest
impl Serialize for ExecuteRequest
impl StructuralPartialEq for ExecuteRequest
Sourceimpl TryFrom<ExecuteRequest> for WireExecuteRequest
impl TryFrom<ExecuteRequest> for WireExecuteRequest
Sourcetype Error = TryFromIntError
type Error = TryFromIntError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<WireExecuteRequest> for ExecuteRequest
impl TryFrom<WireExecuteRequest> for ExecuteRequest
Sourcetype Error = TryFromIntError
type Error = TryFromIntError
The type returned in the event of a conversion error.